@@ -1,9 +1,9 @@
 """Validate and debug DCTAP instances."""
 
-from .tapclasses import TAPShape, TAPStatementConstraint
+from .tapclasses import TAPShape, TAPStatementTemplate
 from .csvreader import csvreader
 
-__version__ = "0.3.2"
+__version__ = "0.3.5"
 
 # Keep version number in sync with:
 # - https://github.com/dcmi/dctap-python/blob/main/docs/conf.py#L28
