@@ -7,13 +7,11 @@ from .utils import is_uri_or_prefixed_uri
 
 
 @dataclass
-class TAPStatementConstraint:
-    """Instances hold TAP/CSV elements related to statement constraints."""
+class TAPStatementTemplate:
+    """Instances hold TAP/CSV elements related to statement templates."""
 
-    # pylint: disable=too-many-instance-attributes
-    # - It's a dataclass, right?
-    # pylint: disable=invalid-name
-    # - propertyID, etc, do not conform to snake-case naming style.
+    # pylint: disable=too-many-instance-attributes # It's a dataclass, right?
+    # pylint: disable=invalid-name # for elements not named in snake case.
 
     propertyID: str = ""
     propertyLabel: str = ""
@@ -25,13 +23,14 @@ class TAPStatementConstraint:
     valueConstraintType: str = ""
     valueShape: str = ""
     note: str = ""
-    sc_warnings: dict = field(default_factory=dict)
-    extra_elements: dict = field(default_factory=dict)
+    state_warns: dict = field(default_factory=dict)
+    state_extras: dict = field(default_factory=dict)
 
     def normalize(self, settings):
         """Normalizes specific fields."""
         # pylint: disable=attribute-defined-outside-init
-        self._warn_if_propertyID_or_valueDataType_not_IRIlike()
+        self._warn_if_propertyID_not_IRIlike()
+        self._warn_if_valueDataType_not_IRIlike()
         self._normalize_booleans_mandatory_repeatable()
         self._valueConstraintType_pattern_warn_if_valueConstraint_not_valid_regex()
         self._valueConstraintType_pattern_warn_if_used_with_value_shape()
@@ -43,17 +42,20 @@ class TAPStatementConstraint:
         self._valueDataType_warn_if_valueNodeType_literal_used_with_any_valueShape()
         self._valueConstraintType_picklist_parse(settings)
         self._valueNodeType_is_from_enumerated_list(settings)
+        self._parse_elements_configured_as_list_elements(settings)
         return self
 
-    def _warn_if_propertyID_or_valueDataType_not_IRIlike(self):
-        """@@@"""
+    def _warn_if_propertyID_not_IRIlike(self):
+        """Records warning if propertyID or valueDataType are not IRI-like."""
         if not is_uri_or_prefixed_uri(self.propertyID):
-            self.sc_warnings[
+            self.state_warns[
                 "propertyID"
             ] = f"{repr(self.propertyID)} is not an IRI or Compact IRI."
+
+    def _warn_if_valueDataType_not_IRIlike(self):
         if self.valueDataType:
             if not is_uri_or_prefixed_uri(self.valueDataType):
-                self.sc_warnings[
+                self.state_warns[
                     "valueDataType"
                 ] = f"{repr(self.valueDataType)} is not an IRI or Compact IRI."
 
@@ -66,10 +68,9 @@ class TAPStatementConstraint:
 
         # pylint: disable=singleton-comparison
         if self.mandatory:
-            # breakpoint(context=5)
             mand = self.mandatory.lower()
             if mand not in valid_values:
-                self.sc_warnings[
+                self.state_warns[
                     "mandatory"
                 ] = f"{repr(self.mandatory)} is not a supported Boolean value."
             if mand in valid_values_for_true:
@@ -78,10 +79,9 @@ class TAPStatementConstraint:
                 self.mandatory = "false"
 
         if self.repeatable:
-            # breakpoint(context=5)
             repeat = self.repeatable.lower()
             if repeat not in valid_values:
-                self.sc_warnings[
+                self.state_warns[
                     "repeatable"
                 ] = f"{repr(self.repeatable)} is not a supported Boolean value."
             if repeat in valid_values_for_true:
@@ -105,7 +105,7 @@ class TAPStatementConstraint:
         if self.valueConstraintType == "iristem":
             for list_item in self.valueConstraint:
                 if not is_uri_or_prefixed_uri(list_item):
-                    self.sc_warnings["valueConstraint"] = (
+                    self.state_warns["valueConstraint"] = (
                         f"Value constraint type is {repr(self.valueConstraintType)}, "
                         f"but {repr(list_item)} does not look like an IRI or "
                         "Compact IRI."
@@ -119,7 +119,7 @@ class TAPStatementConstraint:
             try:
                 re.compile(self.valueConstraint)
             except (re.error, TypeError):
-                self.sc_warnings["valueConstraint"] = (
+                self.state_warns["valueConstraint"] = (
                     f"Value constraint type is {repr(self.valueConstraintType)}, but "
                     f"{repr(self.valueConstraint)} is not a valid regular expression."
                 )
@@ -130,7 +130,7 @@ class TAPStatementConstraint:
         self.valueConstraintType = self.valueConstraintType.lower()
         if self.valueConstraintType == "pattern":
             if self.valueShape:
-                self.sc_warnings["valueConstraintType"] = (
+                self.state_warns["valueConstraintType"] = (
                     f"Value constraint type "
                     f"({repr(self.valueConstraintType)}) "
                     "cannot conform to a value shape."
@@ -139,7 +139,7 @@ class TAPStatementConstraint:
     def _valueConstraintType_languageTag_parse(self, settings):
         """For valueConstraintType languageTag, splits valueConstraint on whitespace."""
         self.valueConstraintType = self.valueConstraintType.lower()
-        sep = settings.get("picklist_item_separator", " ")
+        sep = settings.get("list_item_separator", " ")
         if self.valueConstraintType == "languagetag":
             if self.valueConstraint:
                 self.valueConstraint = self.valueConstraint.split(sep)
@@ -150,7 +150,7 @@ class TAPStatementConstraint:
         """Warns if valueConstraintType used without valueConstraint."""
         if self.valueConstraintType:
             if not self.valueConstraint:
-                self.sc_warnings["valueConstraint"] = (
+                self.state_warns["valueConstraint"] = (
                     f"Value constraint type "
                     f"({repr(self.valueConstraintType)}) "
                     "but no value constraint."
@@ -160,7 +160,7 @@ class TAPStatementConstraint:
     def _valueConstraintType_picklist_parse(self, settings):
         """If valueConstraintType is Picklist, split valueConstraint on whitespace."""
         self.valueConstraintType = self.valueConstraintType.lower()
-        sep = settings.get("picklist_item_separator", " ")
+        sep = settings.get("list_item_separator", " ")
         if self.valueConstraintType == "picklist":
             if self.valueConstraint:
                 self.valueConstraint = self.valueConstraint.split(sep)
@@ -175,7 +175,7 @@ class TAPStatementConstraint:
         if self.valueNodeType:
             self.valueNodeType = self.valueNodeType.lower()  # normalize to lowercase
             if self.valueNodeType not in valid_types:
-                self.sc_warnings[
+                self.state_warns[
                     "valueNodeType"
                 ] = f"{repr(self.valueNodeType)} is not a valid node type."
         return self
@@ -185,7 +185,7 @@ class TAPStatementConstraint:
         self.valueNodeType = self.valueNodeType.lower()
         if self.valueShape:
             if self.valueNodeType == "literal":
-                self.sc_warnings["valueDataType"] = (
+                self.state_warns["valueDataType"] = (
                     "Datatypes are only for literals, "
                     "which cannot conform to a value shape."
                 )
@@ -194,7 +194,7 @@ class TAPStatementConstraint:
         """Value with any datatype cannot conform to a value shape."""
         if self.valueShape:
             if self.valueDataType:
-                self.sc_warnings["valueDataType"] = (
+                self.state_warns["valueDataType"] = (
                     "Datatypes are only for literals, "
                     "which cannot conform to a value shape."
                 )
@@ -204,28 +204,46 @@ class TAPStatementConstraint:
         node_type = self.valueNodeType.lower()
         if node_type in ("iri", "uri", "bnode"):
             if self.valueDataType:
-                self.sc_warnings["valueDataType"] = (
+                self.state_warns["valueDataType"] = (
                     f"Datatypes are only for literals, "
                     f"so node type should not be {repr(self.valueNodeType)}."
                 )
 
+    def _parse_elements_configured_as_list_elements(self, settings):
+        """Parse elements configured as list elementss."""
+        if settings.get("list_item_separator"):
+            separator = settings.get("list_item_separator")
+        else:
+            separator = " "
+
+        if settings.get("list_elements"):
+            list_elements = settings.get("list_elements")
+        else:
+            list_elements = []
+
+        for element in list_elements:
+            if getattr(self, element):
+                setattr(self, element, getattr(self, element).split(separator))
+
+        return self
+
     def get_warnings(self):
-        """Emit warnings dictionary self.sc_warnings, populated by normalize() method."""
-        return dict(self.sc_warnings)
+        """Emit self.state_warns as populated by self.normalize()."""
+        return dict(self.state_warns)
 
 
 @dataclass
 class TAPShape:
-    """Instances hold TAP/CSV row elements related to shapes."""
+    """An instance holds TAP/CSV row elements related to one given, named shape."""
 
     # pylint: disable=invalid-name
     # True that propertyID, etc, do not conform to snake-case naming style.
 
     shapeID: str = ""
     shapeLabel: str = ""
-    sc_list: List[TAPStatementConstraint] = field(default_factory=list)
-    sh_warnings: dict = field(default_factory=dict)
-    extra_elements: dict = field(default_factory=dict)
+    state_list: List[TAPStatementTemplate] = field(default_factory=list)
+    shape_warns: dict = field(default_factory=dict)
+    shape_extras: dict = field(default_factory=dict)
 
     def normalize(self, settings):
         """Normalize values where required."""
@@ -239,5 +257,5 @@ class TAPShape:
         return self
 
     def get_warnings(self):
-        """Emit warnings dictionary self.sh_warnings, populated by normalize() method."""
-        return dict(self.sh_warnings)
+        """Emit warnings dictionary self.shape_warns, populated by normalize() method."""
+        return dict(self.shape_warns)
