@@ -22,18 +22,23 @@ sys.path.insert(0, os.path.abspath("../dctap/"))
 # -- Project information -----------------------------------------------------
 
 project = "dctap-python"
-copyright = "2021, DCMI"
+copyright = "2022, DCMI"
 
 # The full version, including alpha/beta/rc tags
 # See ../dctap/__init__.py
-release = "0.3.2"
+release = "0.3.5"
 
 # -- General configuration ---------------------------------------------------
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
-extensions = ["sphinx.ext.autodoc", "sphinx.ext.napoleon", "sphinx_rtd_theme", "sphinx.ext.autosectionlabel"]
+extensions = [
+    "sphinx.ext.autodoc", 
+    "sphinx.ext.napoleon", 
+    "sphinx_rtd_theme", 
+    "sphinx.ext.autosectionlabel",
+]
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ["_templates"]
