@@ -7,8 +7,58 @@ from dctap.config import get_config
 from dctap.csvreader import _get_rows
 
 
-def test_get_rows_including_header_not_in_DCTAP(tmp_path):
-    """Get rows where one header is not part of the DCTAP model."""
+
+def test_get_rows_when_header_values_are_quoted(tmp_path):
+    """
+    Get rows where header elements are in quotes:
+    - "Text qualifier" characters (single or double quotes) must be removed 
+      from column header
+    """
+    os.chdir(tmp_path)
+    config_dict = get_config()
+    csvfile_path = Path(tmp_path).joinpath("some.csv")
+    csvfile_path.write_text(
+        (
+            '"PropertyID","PropertyLabel"\n'
+            '"dc:creator","Creator"\n'
+        )
+    )
+    csvfile_obj = open(csvfile_path)
+    expected_rows_list = [ 
+        {
+            'propertyID': 'dc:creator',
+            'propertyLabel': 'Creator',
+        }
+    ]
+    actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
+    assert actual_rows_list == expected_rows_list
+
+
+def test_get_rows_where_header_elements_surrounded_by_whitespace(tmp_path):
+    """Get rows where header elements are surrounded by whitespace."""
+    os.chdir(tmp_path)
+    config_dict = get_config()
+    csvfile_path = Path(tmp_path).joinpath("some.csv")
+    csvfile_path.write_text(
+        (
+            " PropertyID ,      PropertyLabel \n"
+            "dc:creator,Creator\n"
+        )
+    )
+    csvfile_obj = open(csvfile_path)
+    expected_rows_list = [ 
+        {
+            'propertyID': 'dc:creator',
+            'propertyLabel': 'Creator',
+        }
+    ]
+    actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
+    assert actual_rows_list == expected_rows_list
+
+
+
+def test_get_rows_including_header_element_not_in_DCTAP(tmp_path):
+    """Get rows where one header element is not part of the DCTAP model."""
     os.chdir(tmp_path)
     config_dict = get_config()
     csvfile_path = Path(tmp_path).joinpath("some.csv")
@@ -28,6 +78,7 @@ def test_get_rows_including_header_not_in_DCTAP(tmp_path):
     actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
     assert actual_rows_list == expected_rows_list
 
+
 def test_get_rows_minimal(tmp_path):
     """Get list of rows, as dicts, from one-row, one-column CSV."""
     os.chdir(tmp_path)
@@ -61,6 +112,7 @@ def test_get_rows_given_customized_element_alias(tmp_path):
     actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
     assert actual_rows_list == expected_rows_list
 
+
 def test_get_rows_fills_in_short_headers_subsequently_with_None(tmp_path):
     """Where headers shorter than rows, extra values collected under header None."""
     os.chdir(tmp_path)
@@ -76,11 +128,13 @@ def test_get_rows_fills_in_short_headers_subsequently_with_None(tmp_path):
             'shapeID': ':a', 
             'propertyID': 'dct:creator', 
             '': 'URI', 
-            None: ['comment', 'comment two']}
+            None: ['comment', 'comment two']
+        }
     ]
     actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
     assert actual_rows_list == expected_rows_list
 
+
 def test_get_rows_fills_in_short_headers_first_with_empty_header(tmp_path):
     """Where headers shorter than rows, adds one empty header."""
     os.chdir(tmp_path)
@@ -93,11 +147,14 @@ def test_get_rows_fills_in_short_headers_first_with_empty_header(tmp_path):
         )
     csvfile_obj = open(csvfile_path)
     expected_rows_list = [
-        {'shapeID': ':a', 'propertyID': 'dct:creator', '': 'URI'}
+        {
+            'shapeID': ':a', 'propertyID': 'dct:creator', '': 'URI'
+        }
     ]
     actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
     assert actual_rows_list == expected_rows_list
 
+
 def test_get_rows_fills_in_short_rows_with_None_values(tmp_path):
     """Fills in short rows with None values."""
     os.chdir(tmp_path)
@@ -115,6 +172,7 @@ def test_get_rows_fills_in_short_rows_with_None_values(tmp_path):
     actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
     assert actual_rows_list == expected_rows_list
 
+
 def test_get_rows_raises_exception_if_first_line_has_no_propertyid(tmp_path):
     """Raises exception if first line of CSV has no propertyID."""
     os.chdir(tmp_path)
@@ -125,6 +183,7 @@ def test_get_rows_raises_exception_if_first_line_has_no_propertyid(tmp_path):
     with pytest.raises(SystemExit):
         _get_rows(csvfile_obj, config_dict)
 
+
 def test_get_rows_with_unknown_column(tmp_path):
     """Non-DCTAP elements kept by _get_rows (but dropped by _get_shapes)."""
     os.chdir(tmp_path)
@@ -160,6 +219,7 @@ def test_get_rows_with_unknown_column(tmp_path):
     actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
     assert actual_rows_list == expected_rows_list
 
+
 def test_get_rows_with_unknown_column2(tmp_path):
     """Passes thru unknown header, lowercased."""
     os.chdir(tmp_path)
@@ -186,6 +246,7 @@ def test_get_rows_with_unknown_column2(tmp_path):
     actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
     assert actual_rows_list == expected_rows_list
 
+
 def test_get_rows_with_simple_csvfile(tmp_path):
     """Another simple CSV with three columns."""
     os.chdir(tmp_path)
@@ -208,6 +269,7 @@ def test_get_rows_with_simple_csvfile(tmp_path):
     actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
     assert actual_rows_list == expected_rows_list
 
+
 def test_liststatements_with_csv_column_outside_dctap_model_are_ignored(tmp_path):
     """CSV columns not part of the DC TAP model are simply ignored."""
     os.chdir(tmp_path)
@@ -226,6 +288,7 @@ def test_liststatements_with_csv_column_outside_dctap_model_are_ignored(tmp_path
     actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
     assert actual_rows_list == expected_rows_list
 
+
 def test_get_rows_correct_a_real_mess(tmp_path):
     """Messiness in headers (extra spaces, punctuation, wrong case) is corrected."""
     os.chdir(tmp_path)
@@ -247,6 +310,7 @@ def test_get_rows_correct_a_real_mess(tmp_path):
     actual_rows_list, actual_warnings = _get_rows(csvfile_obj, config_dict)
     assert actual_rows_list == expected_rows_list
 
+
 def test_get_rows_with_complete_csvfile(tmp_path):
     """Simple CSV with all columns."""
     os.chdir(tmp_path)
@@ -300,6 +364,7 @@ def test_get_rows_with_complete_csvfile(tmp_path):
     assert len(actual_rows_list) == 2
     assert len(expected_rows_list) == 2
 
+
 def test_warns_if_header_not_recognized(tmp_path):
     """@@@"""
     os.chdir(tmp_path)
@@ -323,12 +388,13 @@ def test_warns_if_header_not_recognized(tmp_path):
     assert actual_rows_list == expected_rows_list
     assert len(actual_warnings) == 1
 
+
 def test_does_not_warn_if_non_dctap_header_configured_as_extra(tmp_path):
     """@@@"""
     os.chdir(tmp_path)
     config_dict = get_config()
     config_dict["default_shape_identifier"] = "default"
-    config_dict["extra_statement_constraint_elements"] = ["ricearoni"]
+    config_dict["extra_statement_template_elements"] = ["ricearoni"]
     csvfile_path = Path(tmp_path).joinpath("some.csv")
     csvfile_path.write_text(
         (
